pub async fn readdir<P: AsRef<Path>>( path: P, metadata: bool, ) -> Result<Vec<DirEntry>>
Lists the entries in directory path, optionally including file Metadata for each entry when metadata is true.
path
Metadata
metadata
true